import { Construct } from '@aws-cdk/core';
import { ComputeType } from '@aws-cdk/aws-codebuild';
import { Rule, Schedule, OnEventOptions } from '@aws-cdk/aws-events';
import { CliProps } from './cli';
export interface DependencyCheckProps extends CliProps {
    /**
     * Schedule for dependency check.
     */
    readonly schedule: Schedule;
    /**
     * The type of compute to use for check the repositories.
     * See the {@link ComputeType} enum for the possible values.
     *
     * @default taken from {@link #buildImage#defaultComputeType}
     */
    readonly computeType?: ComputeType;
    /**
     * Custom command to be executed before the dependency check
     *
     * @default `echo "No preCheckCommand!"`
     */
    readonly preCheckCommand?: string;
    /**
     * Version of the dependency check
     *
     * @default 5.3.0
     */
    readonly version?: string;
    /**
     * Name of the project
     *
     * @default taken from {@link #repository#repositoryName}
     */
    readonly projectName?: string;
}
export declare class DependencyCheck extends Construct {
    private readonly checkProject;
    constructor(scope: Construct, id: string, props: DependencyCheckProps);
    /**
     * Defines an event rule which triggers when a check fails.
     */
    onCheckFailed(id: string, options?: OnEventOptions): Rule;
    /**
     * Defines an event rule which triggers when a check starts.
     */
    onCheckStarted(id: string, options?: OnEventOptions): Rule;
    /**
     * Defines an event rule which triggers when a check complets successfully.
     */
    onCheckSucceeded(id: string, options?: OnEventOptions): Rule;
    private makeCloneUrl;
}
